# TOMLdantic

Generate TOML template files from pydantic models.

## Specifications

### TOML - Tom's Obvious, Minimal Language

See the [official TOML specification](https://toml.io/en/v1.0.0) for details.
